@@ -21,7 +21,7 @@ mod dom {
 
     fn dom_as_preserves(v: &Dom) -> io::Result<UnwrappedIOValue> {
         Ok(match v {
-            Dom::One => Value::ByteString(vec![255, 255, 255, 255]),
+            Dom::One => Value::bytestring(vec![255, 255, 255, 255]),
             Dom::Two => Value::symbol(&format!("Dom::{:?}", v)),
         })
     }
